#include "Riostream.h"
#include "TNT2Event.h"


//oscillogram "event" data
ClassImp(SamplePoint);
ClassImp(Signal);

//==================================================================
SamplePoint::SamplePoint() : TObject()
{
  fPoint = 0;
}

SamplePoint::SamplePoint(Short_t sample) : TObject()
{
  fPoint = sample;
}

SamplePoint::SamplePoint(const SamplePoint &orig) : TObject(orig)
{
  fPoint = orig.fPoint;
}

void SamplePoint::Clear(Option_t * /*option*/)
{
  fPoint = 0;
}


//==================================================================
// Create a static TClonesArray at the first call to the constructor,
// then set the pointer fSamples to point to the static pointer. This
// guarantees that the TClonesArray is created only once.
//==================================================================
TClonesArray *Signal::fgSamples = 0;

Signal::Signal() : TObject()
{
  // Create an signal Oscillogram
  fTriggerCounter = 0L;
  fNSamples       = 0;

  //Create TClonesArray if necessary.
  //Set size of TClonesArray to mult ready for filling.
  if(fgSamples == 0)
    fgSamples  = new TClonesArray("SamplePoint",1000);

  fSamples = fgSamples;

  //the following allows Tree->Show(i) to work
  //fSamples = new TClonesArray("SamplePoint",1000);
}

Signal::Signal(const Signal &orig) : TObject(orig)
{
  //copy ctor
  fTriggerCounter = orig.fTriggerCounter;
  
  // create TClonesArray
  fSamples  = (TClonesArray*)orig.fSamples->Clone();
  fNSamples = orig.fNSamples;
}

Signal::~Signal()
{
  Clear();
  if(fSamples) delete fSamples;
}

Signal& Signal::operator=(const Signal &rhs)
{
  //copy
  this->fTriggerCounter = rhs.fTriggerCounter;
  this->fNSamples       = rhs.fNSamples;
  
  // create TClonesArray
  this->fSamples  = (TClonesArray*)rhs.fSamples->Clone();
  return *this;
}

void Signal::AddSamplePoint(Short_t thisPoint)
{
  //cout << "Adding point " << thisPoint << " at sample " << fNSamples << endl;
  TClonesArray &samples = *fSamples;
  new(samples[fNSamples++]) SamplePoint(thisPoint);
}

void Signal::Clear(Option_t *option)
{
  fSamples->Clear(option); //cleear ? TClonesArray
  fNSamples       =   0;
  fTriggerCounter =  0L;   //counter for this channel ?
}
//--------------------------------------------------
// Reset all static objects for this event
//--------------------------------------------------
//void Signal::Reset(Option_t *option)
//{
//  delete fgSamples;  fgSamples  = 0;
//}
//--------------------------------------------------

